Spec-Synthase
=============

|Build Status| |Coverage Status|

Spec-Synthase is a tool to help deal with big swagger files, by building
the swagger specification file from little yaml files.

**Documentation:** http://spec-synthase.readthedocs.io/en/latest/

Usage examples with Zalando/Connexion in production:
====================================================

- `Mozilla/Balrog - Admin Api <https://github.com/mozilla/balrog/blob/c6ac05dc2f4245f33628c1c2cb4b5c5de02c21f5/auslib/web/admin/base.py#L20-L30>`__
- `Mozilla/Balrog - Public Api <https://github.com/mozilla/balrog/blob/c6ac05dc2f4245f33628c1c2cb4b5c5de02c21f5/auslib/web/public/base.py#L30-L37>`__

.. |Build Status| image:: https://travis-ci.org/MicroarrayTecnologia/spec-synthase.svg?branch=master
   :target: https://travis-ci.org/MicroarrayTecnologia/spec-synthase
.. |Coverage Status| image:: https://coveralls.io/repos/github/MicroarrayTecnologia/spec-synthase/badge.svg
   :target: https://coveralls.io/github/MicroarrayTecnologia/spec-synthase
